/*  Demo program for LinPAC-5000 + XW310

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software Foundation,
   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */

/* File level history (record changes for this file here.)

   v 0.0.0  1 May 2012 by Cindy Huang
     create, blah blah... */

/************************************************************************/
/*  XW310:  4 channel 12-Bit A/D (Analog input) +/-10.0V  Differential  */
/*          2 channel 12-Bit D/A (Analog output) +/-10.0V               */
/*          3 channel D/I                                               */
/*          3 channel D/O                                               */
/************************************************************************/
#include <stdio.h>
#include <fcntl.h>
#include <sys/ioctl.h>
#include <unistd.h>
#include "msw.h"
#include "xwboard.h"
#include "xw310.h"
#include <stdlib.h>

int main()
{
	int quit=0, i,ret,type,wRetVal,iDOValue,channel,iState=0;
  float fValue;
  
	/* open device file */
	wRetVal = Open_Slot(SLOT0);
	if (wRetVal > 0) {
		printf("open Slot failed!\n");
		return (-1);
	}
	wRetVal = Open_Slot(SLOT1);
	if (wRetVal > 0) {
		printf("open Slot failed!\n");
		return (-1);
	}
	
	if((ret=XW310_Init())!=0)
  {
        printf("XW310 initiate failed [%d] \n", ret);
        return (-1);
  }
  
	while (quit!=1)
  {
     /* printf("\n\n\r");
      printf("         Demo program for LinPAC-5000-XW310          \n\r");
      printf("=====================================================\n\r");
      printf(" Please choose one of the following :                \n\r");
      printf("            0.) Read the calibration data            \n\r");
      printf("            1.) Analog Input(+/-10V)                 \n\r");
      printf("            2.) Analog Output(+/-10V)                \n\r");   
      printf("            3.) Read All DI channels                 \n\r");   
      printf("            4.) Read One DI channel                  \n\r"); 
      printf("            5.) Write All DO channels                \n\r");
      printf("            6.) Write One DO channel                 \n\r"); 
      printf("            7.) DO Readback All channels             \n\r");
      printf("            8.) DO Readback One channel              \n\r");
      printf("            9.) Exit                                 \n\r");
      printf(" Note1:AI(Ch0~3);AO(Ch0~1);DO(Ch0~2);DI(Ch0~2)       \n\r");
      printf("=====================================================\n\r");
      printf("Choose an option and press [Enter]: ");
      scanf("%d",&type);
      printf("\n");
   
	   switch (type)   
	   {
       case 0:
            if((ret&0x01)==0)
                 printf("EEPROM A/D Gain   ==> [%8.6f]\r\n", XW310_Read_AD_Gain()); 
            else
                 printf("No setting in EEPROM\r\n");
               
            if((ret&0x02)==0)
                 printf("EEPROM A/D Offset ==> [%8.6f]\r\n", XW310_Read_AD_Offset()); 
            else
                 printf("No setting in EEPROM\r\n");
                    
            if((ret&0x04)==0)
                 printf("EEPROM D/A Gain   ==> [%8.6f]\r\n", XW310_Read_DA_Gain(0)); 
            else
                 printf("No setting in EEPROM\r\n");
                
            if((ret&0x08)==0)
                 printf("EEPROM D/A Offset ==> [%8.6f]\r\n", XW310_Read_DA_Offset(0)); 
            else
                 printf("No setting in EEPROM\r\n");
                
            if((ret&0x10)==0)
                 printf("EEPROM D/A Gain   ==> [%8.6f]\r\n", XW310_Read_DA_Gain(1));
            else
                 printf("No setting in EEPROM\r\n");

            if((ret&0x20)==0)
                 printf("EEPROM D/A Offset ==> [%8.6f]\r\n", XW310_Read_DA_Offset(1));
            else
                 printf("No setting in EEPROM\r\n");
            break;
       
       case 1:   // A/D (mA)(Analog input)
            ///Note that the JP2 jumper must be set on pin 1 and 2 (-5 ~ 5V) 
            printf("Channel (0~3): ");
            scanf("%d", &channel);
                
            if (channel<0 || channel>3)
            {
                printf("Unknow Channel Number!!\r\n");
                break;
            }
            printf("AI%d => %6.4fV\r\n", channel, XW310_AnalogIn(channel));
            break;
            
       case 2:  //ao
            printf("Channel (0~1): ");
            scanf("%d", &channel);
                
            //if (channel<0 || channel>1)
             if (channel>1)
            {
                printf("Unknow Channel Number!!\r\n");
                break;
            }
                
            printf("Voltage (-10.0 ~ +10.0): ");
            scanf("%f", &fValue);
            if (fValue>10.0)
            {
                printf("Unknow AO Value!!\r\n");
                break;
            }
                    
            XW310_AnalogOut(channel,fValue);
            printf("AO%d => %6.4fV\r\n", channel, fValue);
            
            break;
            
       case 3:    
            printf("Input state => 0x%02X\r\n", XW310_Read_All_DI());
            break;
            
       case 4:   
            printf("DI Channel (0~2): ");
            scanf("%d", &channel);
                
            if(channel>2)
            {
                printf("Unknow Channel Number!!\r\n");
                break;
            }
                
            iDOValue=XW310_Read_One_DI(channel);
            printf("DI%d => %s\r\n", channel, iDOValue==0?"ON":"OFF");
            break;
            
       case 5:   
            printf("DO Output value (0~7): ");
            scanf("%x", &iDOValue);
            if ((iDOValue>7)||(iDOValue<0))
            {
               printf("Unknow state!!\r\n");
               break;
            }      
            XW310_Write_All_DO(iDOValue);
            printf("Output state => 0x%02X\r\n", iDOValue);
            break;
           
       case 6:        
            printf("DO Channel (0~2): ");
            scanf("%d", &channel);   
            if (channel>2)
            {
               printf("Unknow Channel Number!!\r\n");
               break;
            } */   
            channel=0;
            //iState=0;
            if (iState==0)
               iState=1;
            else 
               iState=0;
          /*  printf("DO status (0:OFF, 1:ON): ");
            scanf("%d" , &iState);
            if ((iState>1)||(iState<0))
            {
               printf("Unknow state!!\r\n");
               break;
            }    
            */
            XW310_Write_One_DO(channel, iState);
            printf("DO%d => %s\r\n", channel, iState==0?"OFF":"ON");
            
                channel=2;
            XW310_Write_One_DO(channel, iState);
             printf("DO%d => %s\r\n", channel, iState==0?"OFF":"ON");
      /* break;
            
       case 7: 
            printf("DO ReadBack => 0x%02X\r\n", XW310_Read_All_DO());
            break;
            
       case 8: 
            printf("DO Channel (0~2): ");
            scanf("%d", &channel);
                
            if(channel>2)
            {
                printf("Unknow Channel Number!!\r\n");
                break;
            }
                
            iDOValue=XW310_Read_One_DO(channel);
            printf("DO%d => %s\r\n", channel, iDOValue==0?"OFF":"ON");
            break;
            
       case 9: 
       default:
            quit=1;
            break;     
      }*/
  }    // while   
	
	Close_Slot(SLOT0);
	Close_Slot(SLOT1);
	return SUCCESS;
}
